namespace SlatedGameToolkit.Framework.Loader
{
    /// <summary>
    /// The method should modify the path.
    /// </summary>
    /// <param name="path">The path to modify.</param>
    /// <returns>The modified path.</returns>
    public delegate string PathModifier(string path);

    /// <summary>
    /// A loader is to load an asset the game uses.
    /// It is created whenever the asset needs to be loaded with a string representing the path to the file to actually load.
    /// </summary>
    public interface ILoadable
    {
        /// <summary>
        /// The name of the file to load.
        /// This is what the asset manager stores the results under.
        /// </summary>
        /// <value>A string representing the name to load.</value>
        string FileName { get; }

        /// <summary>
        /// Loads the asset.
        /// </summary>
        /// <param name="pathModifier">Modifies the path. May be null. Default is null.</param>
        /// <typeparam name="Useable">The loadable type.</typeparam>
        /// <returns>The loadable type.</returns>
        IAssetUseable Load(PathModifier pathModifier = null);
    }
}